"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateManifest = exports.getManifest = void 0;
/* eslint-disable @typescript-eslint/naming-convention */
const vuepress_shared_1 = require("vuepress-shared");
const utils_1 = require("./utils");
const getManifest = async (context, options) => {
    var _a, _b, _c, _d, _e, _f;
    const { base, sourceDir, siteConfig } = context;
    const userManifestPath = vuepress_shared_1.path.resolve(sourceDir, ".vuepress/public/manifest.webmanifest");
    const userManifestJSONPath = vuepress_shared_1.path.resolve(sourceDir, ".vuepress/public/manifest.json");
    const optionManifest = options.manifest || {};
    const userManifest = JSON.parse(vuepress_shared_1.fs.existsSync(userManifestPath)
        ? await vuepress_shared_1.fs.readFile(userManifestPath, "utf8")
        : vuepress_shared_1.fs.existsSync(userManifestJSONPath)
            ? await vuepress_shared_1.fs.readFile(userManifestJSONPath, "utf8")
            : "{}");
    const finalManifest = {
        name: siteConfig.title || ((_b = (_a = siteConfig.locales) === null || _a === void 0 ? void 0 : _a["/"]) === null || _b === void 0 ? void 0 : _b.title) || "Site",
        short_name: siteConfig.title || ((_d = (_c = siteConfig.locales) === null || _c === void 0 ? void 0 : _c["/"]) === null || _d === void 0 ? void 0 : _d.title) || "Site",
        description: siteConfig.description ||
            ((_f = (_e = siteConfig.locales) === null || _e === void 0 ? void 0 : _e["/"]) === null || _f === void 0 ? void 0 : _f.description) ||
            "A site built with vuepress",
        lang: (0, vuepress_shared_1.getRootLang)(context),
        start_url: base,
        scope: base,
        display: "standalone",
        theme_color: options.themeColor || "#46bd87",
        background_color: "#ffffff",
        orientation: "portrait-primary",
        prefer_related_applications: false,
        ...userManifest,
        ...optionManifest,
    };
    return finalManifest;
};
exports.getManifest = getManifest;
const generateManifest = async ({ cwd, outDir }, manifest) => {
    utils_1.logger.load("Generating manifest.webmanifest");
    const manifestPath = vuepress_shared_1.path.resolve(outDir, "manifest.webmanifest");
    await vuepress_shared_1.fs.writeJSON(manifestPath, await manifest, {
        flag: "w",
    });
    utils_1.logger.succeed();
    utils_1.logger.update(`Manifest generated and saved to ${vuepress_shared_1.chalk.cyan(vuepress_shared_1.path.relative(cwd, manifestPath))}!`);
};
exports.generateManifest = generateManifest;
//# sourceMappingURL=generateManifest.js.map